@@ -579,7 +579,7 @@ logRegMultiClass <- R6::R6Class(
                         if (self$options$emmWeights)
                             weights <- 'equal'
                         else
-                            weights <- 'cell'
+                            weights <- 'cells'
 
                         suppressMessages({
                             mm <- try(
